@@ -311,7 +311,7 @@ write_header(FILE   **out,	/* IO - Output file */
     fprintf(*out, "H6 { font-family: %s; }\n", families[_htmlHeadingFont]);
     fputs("SUB { font-size: smaller; }\n", *out);
     fputs("SUP { font-size: smaller; }\n", *out);
-    fputs("PRE { font-family: monospace; margin-left: 36pt; }\n", *out);
+    fprintf(*out, "PRE { font-family: monospace; margin-left: %dpt; }\n", PreIndent);
 
     if (!LinkStyle)
       fputs("A { text-decoration: none; }\n", *out);
@@ -495,16 +495,19 @@ write_title(FILE  *out,		/* I - Output file */
     {
       image_t *img = image_load(TitleImage, !OutputColor);
 
-      if (OutputFiles)
-	fprintf(out, "<IMG SRC=\"%s\" BORDER=\"0\" WIDTH=\"%d\" HEIGHT=\"%d\" "
-	             "ALT=\"%s\"><BR>\n",
-        	file_basename((char *)TitleImage), img->width, img->height,
-		title ? (char *)title : "");
-      else
-	fprintf(out, "<IMG SRC=\"%s\" BORDER=\"0\" WIDTH=\"%d\" HEIGHT=\"%d\" "
-	             "ALT=\"%s\"><BR>\n",
-        	TitleImage, img->width, img->height,
-		title ? (char *)title : "");
+      if (img)
+      {
+	if (OutputFiles)
+	  fprintf(out, "<IMG SRC=\"%s\" BORDER=\"0\" WIDTH=\"%d\" HEIGHT=\"%d\" "
+		       "ALT=\"%s\"><BR>\n",
+		  file_basename((char *)TitleImage), img->width, img->height,
+		  title ? (char *)title : "");
+	else
+	  fprintf(out, "<IMG SRC=\"%s\" BORDER=\"0\" WIDTH=\"%d\" HEIGHT=\"%d\" "
+		       "ALT=\"%s\"><BR>\n",
+		  TitleImage, img->width, img->height,
+		  title ? (char *)title : "");
+      }
     }
 
     if (title != NULL)
