@@ -3,7 +3,7 @@
 //
 //     https://www.msweet.org/mmd
 //
-// Copyright © 2017-2024 by Michael R Sweet.
+// Copyright © 2017-2025 by Michael R Sweet.
 //
 // Licensed under Apache License v2.0.	See the file "LICENSE" for more
 // information.
@@ -92,7 +92,7 @@ typedef struct _mmd_filebuf_s		// Buffered file
 {
   mmd_iocb_t	cb;			// Read callback function
   void		*cbdata;		// Read callback data
-  char		buffer[65536],		// Buffer
+  char		buffer[8192],		// Buffer
 		*bufptr,		// Pointer into buffer
 		*bufend;		// End of buffer
 } _mmd_filebuf_t;
@@ -544,7 +544,7 @@ mmdLoadIO(mmd_t      *root,		// I - Root node for document or `NULL` for a new d
       block = NULL;
       continue;
     }
-    else if (*lineptr == '>' && (lineptr - linestart) < 4)
+    else if (stackptr->parent->type != MMD_TYPE_CODE_BLOCK && *lineptr == '>' && (lineptr - linestart) < 4)
     {
       // Block quote.  See if there is an existing blockquote...
       DEBUG_printf("	 BLOCKQUOTE (stackptr=%ld)\n", stackptr - stack);
@@ -1059,6 +1059,8 @@ mmdLoadIO(mmd_t      *root,		// I - Root node for document or `NULL` for a new d
 	break;
       else if (line[0] == '>' && *ptr == '>')
 	memmove(ptr, ptr + 1, strlen(ptr));
+
+      DEBUG2_printf("        line=\"%s\"\n", line);
     }
 
     mmd_parse_inline(&doc, block, lineptr);
@@ -1493,7 +1495,7 @@ mmd_parse_inline(_mmd_doc_t *doc,	// I - Document
 
   for (text = NULL, type = MMD_TYPE_NORMAL_TEXT; *lineptr; lineptr ++)
   {
-    DEBUG2_printf("mmd_parse_inline: lineptr=%p(\"%32.32s...\"), type=%d, text=%p, whitespace=%d\n", lineptr, lineptr, type, text, whitespace);
+    DEBUG2_printf("mmd_parse_inline: lineptr=%p(\"%s\"), type=%d, text=%p, whitespace=%d\n", lineptr, lineptr, type, text, whitespace);
 
     if (isspace(*lineptr & 255) && type != MMD_TYPE_CODE_TEXT)
     {
@@ -2090,6 +2092,8 @@ mmd_read_buffer(_mmd_filebuf_t *file)	// I - File buffer
   if (file->bufptr && file->bufptr > file->buffer)
   {
     // Discard previous characters in the buffer.
+    DEBUG2_printf("mmd_read_buffer: before buffer=\"%s\"\n", file->bufptr);
+
     memmove(file->buffer, file->bufptr, file->bufend - file->bufptr);
     file->bufend -= (file->bufptr - file->buffer);
   }
@@ -2099,11 +2103,13 @@ mmd_read_buffer(_mmd_filebuf_t *file)	// I - File buffer
     file->bufend = file->buffer;
   }
 
-  if ((bytes = (file->cb)(file->cbdata, file->bufend, sizeof(file->buffer) - (size_t)(file->bufend - file->buffer - 1))) > 0)
+  if ((bytes = (file->cb)(file->cbdata, file->bufend, sizeof(file->buffer) - (size_t)(file->bufend - file->buffer) - 1)) > 0)
     file->bufend += bytes;
 
   *(file->bufend) = '\0';
   file->bufptr    = file->buffer;
+
+  DEBUG2_printf("mmd_read_buffer: after buffer=\"%s\"\n", file->buffer);
 }
 
 
@@ -2161,6 +2167,8 @@ mmd_read_line(_mmd_filebuf_t *file,	// I - File buffer
   else if (!strchr(file->bufptr, '\n'))
     mmd_read_buffer(file);
 
+  DEBUG2_printf("mmd_read_line: Returning \"%s\"\n", line);
+
   return (line);
 }
 
